##  Single- and Multiple-Select Fields and Tag Groups
Tags can be part of a tag group, and the tag groups come in two different types:
  1. Single-Select Tag Groups: Only a single tag of this group can be assigned to a fact sheet.
  2. Multiple-Select Tag Groups: Multiple tags of this group can be assigned to a fact sheet.


In our meta model, there are corresponding fields of type single-select and multiple-select. Thanks to an Excel import and export, it is easy to transfer the values of a tag group to a corresponding field and vice versa.
